<?php
 namespace App\Controller\Frontend; use Symfony\Component\HttpFoundation\Request; use Symfony\Component\HttpFoundation\Response; use Symfony\Component\Form\Form; use Symfony\Component\Form\Extension\Core\Type\SubmitType; use Symfony\Contracts\Translation\TranslatorInterface; use Symfony\Component\Validator\Validator\ValidatorInterface; use Symfony\Component\Validator\ConstraintViolationList; use App\Controller\Controller; use App\Event\EventQueue; use App\Service\Logger; use App\Entity\Site as SiteEntity; use App\Entity\Certificate as CertificateEntity; use App\Entity\NodejsSettings as NodejsSettingsEntity; use App\Entity\PhpSettings as PhpSettingsEntity; use App\Entity\PythonSettings as PythonSettingsEntity; use App\Entity\Database as DatabaseEntity; use App\Entity\DatabaseUser as DatabaseUserEntity; use App\Entity\DatabaseServer as DatabaseServerEntity; use App\Entity\User as UserEntity; use App\Entity\Manager\ConfigManager; use App\Entity\Manager\SiteManager as SiteEntityManager; use App\Entity\Manager\CertificateManager as CertificateEntityManager; use App\Entity\Manager\DatabaseManager as DatabaseEntityManager; use App\Entity\Manager\DatabaseUserManager as DatabaseUserEntityManager; use App\Entity\Manager\DatabaseServerManager as DatabaseServerEntityManager; use App\Entity\Manager\VhostTemplateManager as VhostTemplateEntityManager; use App\Database\Connection as DatabaseConnection; use App\Database\Manager as DatabaseManager; use App\Site\Nginx\Vhost\StaticTemplate as StaticVhostTemplate; use App\Site\Nginx\Vhost\PhpTemplate as PhpVhostTemplate; use App\Site\Nginx\Vhost\PythonTemplate as PythonVhostTemplate; use App\Site\Nginx\Vhost\ReverseProxyTemplate as ReverseProxyVhostTemplate; use App\Site\Nginx\Vhost\Processor\RedirectDomain as RedirectDomainProcessor; use App\Site\Nginx\Vhost\Processor\RedirectServerName as RedirectServerNameProcessor; use App\Site\Nginx\Vhost\Processor\ServerName as ServerNameProcessor; use App\Site\Parser\DomainName as DomainNameParser; use App\Site\Ssl\Generator\RsaKeyGenerator; use App\Site\Creator\NodejsSite as NodejsSiteCreator; use App\Site\Creator\StaticSite as StaticSiteCreator; use App\Site\Creator\PhpSite as PhpSiteCreator; use App\Site\Creator\PythonSite as PythonSiteCreator; use App\Site\Creator\ReverseProxySite as ReverseProxySiteCreator; use App\Site\Ssl\DistinguishedName; use App\Site\Ssl\Generator\CsrGenerator; use App\Site\Ssl\Util\Openssl; use App\Site\NodejsSite; use App\Site\StaticSite; use App\Site\PhpSite; use App\Site\PythonSite; use App\Site\ReverseProxySite; use App\Util\PasswordGenerator; use App\Site\Application\WordPressInstaller; use App\Service\Crypto; class NewSiteController extends Controller { private const WORDPRESS_VHOST_TEMPLATE_NAME = "\127\157\162\x64\x50\x72\145\163\163"; private const NODEJS_VHOST_TEMPLATE_NAME = "\116\x6f\x64\145\152\x73"; private const STATIC_SITE_VHOST_TEMPLATE_NAME = "\x53\x74\141\164\151\x63"; private const PYTHON_VHOST_TEMPLATE_NAME = "\120\171\x74\150\x6f\156"; private const REVERSE_PROXY_VHOST_TEMPLATE_NAME = "\x52\x65\x76\x65\x72\163\145\x50\x72\157\170\171"; private const VARNISH_CACHE_SERVER = "\x31\62\67\x2e\60\x2e\x30\56\x31\x3a\x36\60\70\61"; private const PASSWORD_LENGTH = 20; private ConfigManager $configManager; private SiteEntityManager $siteEntityManager; private CertificateEntityManager $certificateEntityManager; private DatabaseEntityManager $databaseEntityManager; private DatabaseUserEntityManager $databaseUserEntityManager; private DatabaseServerEntityManager $databaseServerEntityManager; private DomainNameParser $domainNameParser; private VhostTemplateEntityManager $vhostTemplateEntityManager; private ValidatorInterface $validator; private array $wordPressDefaultConfigValues = ["\x46\123\137\x4d\x45\x54\110\117\x44" => ["\166\141\154\165\x65" => "\x64\151\x72\x65\143\164", "\162\x61\x77" => false], "\127\x50\137\x44\x45\x42\125\x47\137\x44\x49\x53\x50\114\x41\x59" => ["\x76\141\x6c\x75\x65" => "\146\141\154\163\145", "\162\141\x77" => true], "\127\x50\x5f\104\x45\x42\125\x47\x5f\x4c\x4f\x47" => ["\x76\141\154\165\x65" => "\164\162\x75\x65", "\x72\141\x77" => true], "\x43\117\116\103\101\x54\105\116\101\x54\105\x5f\x53\103\122\x49\120\x54\x53" => ["\x76\x61\x6c\x75\145" => "\146\x61\x6c\x73\145", "\x72\141\x77" => true], "\x41\x55\124\x4f\123\101\126\105\137\x49\116\x54\x45\122\126\x41\114" => ["\166\141\x6c\165\145" => 600, "\x72\141\167" => true], "\x57\x50\x5f\x50\x4f\x53\124\x5f\x52\105\126\x49\x53\x49\117\x4e\x53" => ["\166\141\x6c\165\x65" => 5, "\x72\141\x77" => true], "\x45\115\x50\x54\131\137\x54\122\x41\x53\x48\x5f\x44\101\131\123" => ["\166\x61\154\x75\145" => 21, "\x72\141\167" => true]]; private array $wordPressMultiSiteConfigValues = ["\x57\120\137\x41\x4c\x4c\117\127\137\x4d\125\114\124\111\x53\111\x54\105" => ["\166\x61\154\x75\x65" => "\x74\162\x75\145", "\162\x61\167" => true], "\115\x55\114\124\x49\123\111\124\105" => ["\166\x61\154\165\x65" => "\164\162\x75\x65", "\162\141\167" => true], "\123\x55\x42\x44\x4f\x4d\101\x49\116\137\111\116\x53\x54\x41\x4c\x4c" => ["\x76\x61\x6c\x75\145" => "\x66\141\x6c\x73\x65", "\162\141\x77" => true], "\x44\x4f\x4d\x41\111\116\137\103\x55\x52\122\x45\x4e\x54\x5f\123\x49\124\105" => ["\166\x61\x6c\x75\x65" => '', "\x72\x61\167" => false], "\x50\x41\124\x48\137\x43\x55\122\x52\x45\116\124\137\123\x49\124\x45" => ["\166\x61\x6c\x75\x65" => "\57", "\x72\141\167" => false], "\123\x49\x54\x45\137\x49\104\137\103\125\x52\x52\x45\x4e\x54\x5f\x53\111\124\105" => ["\x76\141\154\x75\145" => 1, "\162\141\x77" => true], "\102\x4c\117\x47\137\x49\x44\137\103\125\122\x52\105\116\x54\x5f\123\111\x54\x45" => ["\166\x61\x6c\x75\145" => 1, "\x72\x61\x77" => true]]; public function __construct(ConfigManager $configManager, SiteEntityManager $siteEntityManager, CertificateEntityManager $certificateEntityManager, DatabaseEntityManager $databaseEntityManager, DatabaseUserEntityManager $databaseUserEntityManager, DatabaseServerEntityManager $databaseServerEntityManager, VhostTemplateEntityManager $vhostTemplateEntityManager, DomainNameParser $domainNameParser, ValidatorInterface $validator, TranslatorInterface $translator, Logger $logger) { goto Cc19d; Da621: $this->validator = $validator; goto Aaeeb; F40fd: $this->databaseServerEntityManager = $databaseServerEntityManager; goto ad820; Aaeeb: parent::__construct($translator, $logger); goto A6ddf; Cc19d: $this->configManager = $configManager; goto B0337; ad820: $this->vhostTemplateEntityManager = $vhostTemplateEntityManager; goto c42f2; c42f2: $this->domainNameParser = $domainNameParser; goto Da621; Ea7e1: $this->certificateEntityManager = $certificateEntityManager; goto Dbe0d; B7e0f: $this->databaseUserEntityManager = $databaseUserEntityManager; goto F40fd; Dbe0d: $this->databaseEntityManager = $databaseEntityManager; goto B7e0f; B0337: $this->siteEntityManager = $siteEntityManager; goto Ea7e1; A6ddf: } public function index(Request $request) : Response { goto C2f5d; D7b7d: if (true === $hasPermissions) { goto eccfb; } goto a90ad; a90ad: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\x5f\x73\151\x74\145\x73")); goto Dac7f; Dac7f: goto F61f3; goto b6361; b19ba: return $response; goto C521b; D196e: $user = $this->getUser(); goto cd636; ccea4: F61f3: goto b19ba; cd636: $response = $this->render("\x46\x72\x6f\156\164\145\156\x64\57\x53\x69\x74\x65\x2f\x4e\145\167\57\151\x6e\x64\145\x78\56\150\164\x6d\154\56\x74\167\x69\147", ["\165\163\145\x72" => $user]); goto ccea4; C2f5d: $hasPermissions = $this->hasPermissions(); goto D7b7d; b6361: eccfb: goto D196e; C521b: } public function newPythonSite(Request $request) : Response { goto Fb0b2; bf7b8: $user = $this->getUser(); goto Cad7b; Cdbe9: goto e469c; goto B0237; Ad322: f4f4c: goto A44f8; Eaca0: F60be: goto Ad322; Fdb07: if (!(false === is_null($response))) { goto e804b; } goto a8582; B62af: $form->handleRequest($request); goto ba797; eb5db: e804b: goto Eaca0; ddb47: if (true === $hasPermissions) { goto A3df0; } goto A6169; B0237: A3df0: goto bf7b8; ba797: if (!(true === $form->isSubmitted())) { goto F60be; } goto c064a; a8ef2: $form = $this->createPythonSiteForm($pythonSettings); goto fa72b; fa72b: if (!(true === $request->isMethod("\x50\117\x53\124"))) { goto f4f4c; } goto B62af; A6169: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\163\151\164\145\x73")); goto Cdbe9; A44f8: $response = $this->render("\x46\162\157\x6e\x74\x65\156\x64\x2f\x53\151\x74\145\57\116\x65\x77\x2f\x70\x79\164\x68\x6f\156\56\x68\x74\155\154\x2e\x74\x77\151\147", ["\165\163\145\x72" => $user, "\x66\157\x72\x6d" => $form->createView(), "\146\157\162\155\105\x72\162\157\x72\x73" => $this->formErrors]); goto F4a54; Cad7b: $pythonSettings = new PythonSettingsEntity(); goto a8ef2; c064a: $response = $this->handleCreatePythonSiteForm($request, $form); goto Fdb07; Fb0b2: $hasPermissions = $this->hasPermissions(); goto ddb47; F5117: return $response; goto c3d66; a8582: return $response; goto eb5db; F4a54: e469c: goto F5117; c3d66: } private function createPythonSiteForm(PythonSettingsEntity $pythonSettings) : Form { goto Fe046; b797f: return $form; goto C3702; d3db1: $form->add("\x73\165\142\x6d\151\x74", SubmitType::class, ["\141\164\164\162" => ["\x63\x6c\141\163\163" => "\x62\164\x6e\x20\x62\x74\x6e\x2d\x6c\147\x20\x62\164\156\55\142\x6c\165\x65"], "\x6c\141\142\x65\x6c" => "\103\162\145\141\164\145"]); goto b797f; Fe046: $form = $this->createForm("\x41\x70\x70\x5c\106\x6f\162\155\134\123\x69\x74\x65\116\145\167\x50\x79\164\x68\157\156\124\x79\x70\145", $pythonSettings, ["\141\x63\x74\151\x6f\x6e" => $this->generateUrl("\143\154\160\137\x73\x69\x74\145\x5f\x70\171\x74\150\x6f\156\137\156\145\x77"), "\155\x65\x74\150\157\x64" => "\x50\x4f\123\x54", "\141\x74\x74\162" => ["\151\x64" => "\x6e\145\167\x2d\160\171\164\x68\x6f\x6e\55\163\x69\164\x65\55\146\x6f\162\x6d"]]); goto d3db1; C3702: } private function handleCreatePythonSiteForm(Request $request, Form $form) { goto Fe236; D9128: B033c: goto A92ac; e7552: Aa300: goto fe1ec; acdef: $this->formErrors = $this->getErrorMessages($form); goto D5514; D5514: goto Aa300; goto D9128; Fe236: if (true === $form->isValid()) { goto B033c; } goto acdef; A92ac: try { goto Fb149; cb0e4: $this->createPythonSite($domainName, $pythonVersion, $port, $siteUser, $siteUserPassword); goto aca98; D1091: $session->getFlashBag()->set("\x73\x75\x63\x63\x65\163\163", $this->translator->trans("\123\151\164\145\x20\x68\141\163\40\142\x65\x65\156\x20\x63\x72\145\x61\x74\x65\144\56")); goto Cc91f; F873a: $siteUser = $form->get("\163\151\164\145\x55\163\145\162")->getData(); goto efdf0; Dd620: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto e8ed4; bf55d: $port = $form->get("\x70\157\162\x74")->getData(); goto F873a; aca98: $eventData = ["\163\151\x74\x65" => $domainName, "\x73\x69\164\x65\x55\163\x65\x72" => $siteUser, "\160\x79\x74\x68\157\x6e\x56\145\162\163\151\157\156" => $pythonVersion, "\160\x6f\x72\x74" => $port]; goto ddcb0; Cc91f: $response = $this->redirect($this->generateUrl("\x63\154\x70\x5f\x73\151\x74\145\x73")); goto B5535; e8ed4: if (false === is_null($vhostTemplateEntity)) { goto ceb52; } goto bd320; Fb149: $session = $request->getSession(); goto C82d7; efdf0: $siteUserPassword = $form->get("\163\x69\x74\145\125\x73\x65\x72\x50\x61\163\163\x77\157\x72\144")->getData(); goto aef0a; Fa1aa: $pythonVersion = $form->get("\160\171\164\x68\x6f\156\x56\145\x72\163\151\x6f\156")->getData(); goto bf55d; B5dd3: $user = $this->getUser(); goto cb0e4; C82d7: $domainName = $form->get("\x64\157\155\141\x69\x6e\116\141\155\145")->getData(); goto Fa1aa; aef0a: $vhostTemplateName = self::PYTHON_VHOST_TEMPLATE_NAME; goto Dd620; Ace19: goto F04e4; goto a5f4d; ddcb0: EventQueue::addEvent(EventQueue::EVENT_SITE_PYTHON_CREATE, $user, $eventData, $request); goto D1091; a5f4d: ceb52: goto B5dd3; B5535: return $response; goto bfa37; bd320: throw new \Exception(sprintf("\126\150\157\x73\x74\40\x74\145\155\x70\154\141\x74\145\40\x22\45\x73\42\x20\x6e\x6f\164\40\x66\157\165\156\144\56", $vhostTemplateName)); goto Ace19; bfa37: F04e4: goto Bb6f6; Bb6f6: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\156\x67\145\162", $this->translator->trans("\x41\x6e\40\145\162\x72\x6f\162\x20\x68\x61\x73\x20\x6f\143\x63\x75\x72\162\x65\144\54\x20\145\162\x72\x6f\x72\x20\x6d\145\x73\x73\141\x67\145\72\40\45\x65\x72\x72\x6f\162\x4d\145\x73\x73\x61\x67\145\x25", ["\x25\x65\162\x72\x6f\162\x4d\145\163\163\x61\x67\x65\x25" => $e->getMessage()])); } goto e7552; fe1ec: } public function newReverseProxy(Request $request) : Response { goto a1c71; e2588: return $response; goto a86fb; e6f5c: if (!(true === $form->isSubmitted())) { goto a6065; } goto F8de7; F3f9a: goto Ffffb; goto B12c2; bbef2: if (!(false === is_null($response))) { goto Ae0df; } goto e2588; B12c2: C0224: goto c96dc; a86fb: Ae0df: goto F28fa; a1c71: $hasPermissions = $this->hasPermissions(); goto c411a; c96dc: $user = $this->getUser(); goto Bc8f0; Dff9f: Ffffb: goto Bbfbe; A337e: if (!(true === $request->isMethod("\120\117\x53\124"))) { goto c00d2; } goto e9996; Bbfbe: return $response; goto C6dad; ef80d: $response = $this->redirect($this->generateUrl("\143\154\160\137\x73\151\164\x65\x73")); goto F3f9a; F28fa: a6065: goto c9214; F8de7: $response = $this->handleReverseProxyForm($request, $form); goto bbef2; Bc8f0: $form = $this->createReverseProxyForm(); goto A337e; c411a: if (true === $hasPermissions) { goto C0224; } goto ef80d; e9996: $form->handleRequest($request); goto e6f5c; E26d9: $response = $this->render("\106\x72\x6f\156\x74\x65\x6e\144\x2f\x53\151\164\145\57\116\145\167\x2f\x72\145\166\x65\x72\163\x65\x2d\160\x72\x6f\170\x79\x2e\x68\164\155\154\x2e\x74\x77\151\147", ["\165\163\x65\162" => $user, "\x66\157\x72\155" => $form->createView(), "\x66\157\162\155\105\x72\162\x6f\x72\163" => $this->formErrors]); goto Dff9f; c9214: c00d2: goto E26d9; C6dad: } private function createReverseProxyForm() : Form { goto f99cf; edf7a: return $form; goto b9a00; f99cf: $form = $this->createForm("\101\160\160\134\x46\x6f\x72\155\x5c\x53\x69\x74\x65\x4e\x65\x77\122\145\x76\x65\162\163\145\120\x72\157\170\x79\x54\171\x70\145", [], ["\141\x63\164\x69\157\x6e" => $this->generateUrl("\x63\154\x70\137\x73\x69\x74\145\x5f\162\145\x76\145\x72\163\x65\x5f\160\x72\x6f\170\171\137\x6e\145\x77"), "\155\x65\164\150\x6f\144" => "\x50\117\123\x54", "\x61\164\164\x72" => ["\x69\144" => "\156\145\x77\55\162\145\x76\x65\162\x73\x65\x2d\x70\162\x6f\170\171\55\146\x6f\x72\155"]]); goto f4e09; f4e09: $form->add("\163\x75\x62\x6d\151\164", SubmitType::class, ["\x61\x74\164\162" => ["\143\x6c\x61\x73\163" => "\142\164\x6e\40\x62\164\156\55\154\x67\x20\142\164\156\55\x62\x6c\165\x65"], "\x6c\x61\142\x65\154" => "\103\162\x65\141\164\x65"]); goto edf7a; b9a00: } private function handleReverseProxyForm(Request $request, Form $form) { goto d302b; eb8b6: try { goto f273a; d7540: $eventData = ["\163\x69\164\x65" => $domainName, "\x73\x69\164\x65\x55\163\x65\x72" => $siteUser, "\162\145\x76\x65\x72\x73\x65\120\x72\157\x78\171\125\x72\154" => $reverseProxyUrl]; goto E518f; cf316: $response = $this->redirect($this->generateUrl("\143\x6c\x70\137\x73\x69\164\x65\x73")); goto F9095; Cd22c: $this->createReverseProxySite($domainName, $reverseProxyUrl, $siteUser, $siteUserPassword); goto d7540; fc105: $siteUserPassword = $form->get("\163\x69\164\x65\x55\163\x65\x72\x50\x61\163\163\x77\157\162\144")->getData(); goto B3243; b0d63: af29a: goto a9972; a0186: $vhostTemplateName = self::REVERSE_PROXY_VHOST_TEMPLATE_NAME; goto d5eba; Fe4ae: $session->getFlashBag()->set("\x73\x75\x63\x63\x65\163\163", $this->translator->trans("\122\145\166\145\x72\x73\145\40\120\162\157\170\x79\40\x68\141\x73\x20\142\x65\x65\156\40\x63\162\x65\x61\x74\x65\144\56")); goto cf316; E518f: EventQueue::addEvent(EventQueue::EVENT_SITE_REVERSE_PROXY_CREATE, $user, $eventData, $request); goto Fe4ae; a278f: Dc229: goto b098c; d5653: goto af29a; goto a278f; b098c: $user = $this->getUser(); goto Cd22c; f273a: $session = $request->getSession(); goto C6a77; F9095: return $response; goto b0d63; Dad2a: throw new \Exception(sprintf("\126\150\x6f\x73\164\40\x74\145\x6d\x70\x6c\141\x74\x65\40\x22\45\x73\42\x20\156\x6f\164\x20\x66\157\165\x6e\144\56", $vhostTemplateName)); goto d5653; C6a77: $domainName = $form->get("\x64\x6f\155\x61\151\156\116\x61\x6d\x65")->getData(); goto ddf4c; ddf4c: $siteUser = $form->get("\163\x69\164\x65\125\x73\x65\162")->getData(); goto fc105; d5eba: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto B7103; B3243: $reverseProxyUrl = $form->get("\162\145\x76\x65\x72\163\x65\x50\x72\157\x78\x79\125\x72\x6c")->getData(); goto a0186; B7103: if (false === is_null($vhostTemplateEntity)) { goto Dc229; } goto Dad2a; a9972: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\x6e\147\x65\x72", $this->translator->trans("\101\x6e\x20\145\x72\x72\157\162\x20\x68\x61\x73\40\x6f\x63\x63\165\x72\162\145\144\x2c\40\x65\162\162\x6f\x72\40\155\x65\x73\163\x61\x67\x65\x3a\40\x25\x65\162\x72\x6f\162\x4d\145\x73\163\x61\x67\x65\45", ["\x25\x65\162\162\x6f\162\115\x65\163\163\x61\x67\145\45" => $e->getMessage()])); } goto f96ed; Ed52a: $this->formErrors = $this->getErrorMessages($form); goto d8447; d8447: goto abc94; goto ac90f; ac90f: f22c8: goto eb8b6; d302b: if (true === $form->isValid()) { goto f22c8; } goto Ed52a; f96ed: abc94: goto aa027; aa027: } public function newNodejsSite(Request $request) : Response { goto Cacc6; C6e65: c8b95: goto c2876; c2876: $user = $this->getUser(); goto fc60b; Bffc8: if (!(false === is_null($response))) { goto Eca5f; } goto fca8f; Bc5aa: $form->handleRequest($request); goto cc1f7; C4a31: F079f: goto da1d9; da1d9: return $response; goto E8ab8; Cacc6: $hasPermissions = $this->hasPermissions(); goto c8d0b; b6158: $response = $this->render("\106\162\157\156\x74\x65\x6e\x64\x2f\123\x69\x74\x65\x2f\116\145\x77\x2f\x6e\x6f\x64\145\x6a\x73\x2e\x68\x74\x6d\x6c\56\x74\167\151\x67", ["\x75\x73\145\x72" => $user, "\x66\x6f\162\x6d" => $form->createView(), "\x66\157\x72\155\x45\x72\x72\157\162\x73" => $this->formErrors]); goto C4a31; e0f08: if (!(true === $request->isMethod("\x50\117\123\124"))) { goto a01c9; } goto Bc5aa; E6bf7: Eca5f: goto C4105; cfe6b: a01c9: goto b6158; fc60b: $nodejsSettings = new NodejsSettingsEntity(); goto Bd7e6; a7b6b: $response = $this->handleCreateNodejsSiteForm($request, $form); goto Bffc8; Bd7e6: $form = $this->createNodejsSiteForm($nodejsSettings); goto e0f08; a9ed4: goto F079f; goto C6e65; Ea6a5: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\163\x69\x74\x65\x73")); goto a9ed4; C4105: Cfb2f: goto cfe6b; fca8f: return $response; goto E6bf7; cc1f7: if (!(true === $form->isSubmitted())) { goto Cfb2f; } goto a7b6b; c8d0b: if (true === $hasPermissions) { goto c8b95; } goto Ea6a5; E8ab8: } private function createNodejsSiteForm(NodejsSettingsEntity $nodejsSettings) : Form { goto Aceca; Afd32: return $form; goto ddf26; dc7c9: $form->add("\163\165\142\x6d\151\x74", SubmitType::class, ["\x61\164\164\162" => ["\143\154\141\163\163" => "\142\164\x6e\40\142\164\156\x2d\154\x67\40\x62\164\x6e\55\142\154\165\145"], "\154\141\x62\145\x6c" => "\x43\162\145\x61\x74\x65"]); goto Afd32; Aceca: $form = $this->createForm("\101\x70\x70\x5c\x46\x6f\x72\155\x5c\123\151\x74\145\x4e\145\x77\116\157\144\x65\152\x73\x54\x79\160\145", $nodejsSettings, ["\141\143\x74\151\157\156" => $this->generateUrl("\143\154\x70\x5f\x73\151\x74\145\x5f\x6e\x6f\144\145\x6a\163\x5f\156\145\167"), "\x6d\145\x74\x68\157\x64" => "\x50\117\123\x54", "\x61\164\x74\x72" => ["\x69\x64" => "\156\x65\x77\x2d\156\157\144\145\x6a\x73\x2d\163\151\x74\145\55\x66\x6f\x72\155"]]); goto dc7c9; ddf26: } private function handleCreateNodejsSiteForm(Request $request, Form $form) { goto fa26a; Ad5de: E9c35: goto d2f61; F96b7: goto E9c35; goto d0fbe; b9d28: $this->formErrors = $this->getErrorMessages($form); goto F96b7; Ee7ae: try { goto F337a; fbfa0: goto b9eb3; goto b4fc0; d7e1e: $port = $form->get("\x70\157\x72\164")->getData(); goto Bff21; f484b: return $response; goto d45b1; cd80a: $domainName = $form->get("\x64\x6f\155\x61\x69\x6e\x4e\x61\x6d\145")->getData(); goto bfc1d; e6d3f: $response = $this->redirect($this->generateUrl("\x63\x6c\160\x5f\x73\x69\x74\x65\163")); goto f484b; fd5fa: $session->getFlashBag()->set("\163\x75\x63\x63\145\163\x73", $this->translator->trans("\123\151\164\x65\x20\150\x61\163\40\142\x65\145\156\40\143\x72\145\141\x74\145\144\56")); goto e6d3f; Cf17c: EventQueue::addEvent(EventQueue::EVENT_SITE_NODEJS_CREATE, $user, $eventData, $request); goto fd5fa; E73a9: $vhostTemplateName = self::NODEJS_VHOST_TEMPLATE_NAME; goto d9610; b4fc0: C8e8c: goto cce65; d9610: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto A971a; A585f: $siteUserPassword = $form->get("\x73\x69\164\x65\x55\163\145\x72\x50\x61\163\163\x77\x6f\162\144")->getData(); goto E73a9; A971a: if (false === is_null($vhostTemplateEntity)) { goto C8e8c; } goto ef6c2; d45b1: b9eb3: goto A5223; bfc1d: $nodejsVersion = $form->get("\x6e\157\144\145\152\x73\126\x65\162\163\151\x6f\156")->getData(); goto d7e1e; dca14: $eventData = ["\163\x69\164\145" => $domainName, "\x73\x69\164\x65\125\x73\145\x72" => $siteUser, "\156\157\x64\145\x6a\x73\126\x65\162\x73\151\157\x6e" => $nodejsVersion, "\x70\x6f\x72\164" => $port]; goto Cf17c; cce65: $user = $this->getUser(); goto c9c51; F337a: $session = $request->getSession(); goto cd80a; ef6c2: throw new \Exception(sprintf("\126\x68\157\163\x74\x20\164\x65\x6d\160\154\141\x74\145\40\x22\45\163\x22\40\x6e\157\x74\40\146\157\165\156\144\56", $vhostTemplateName)); goto fbfa0; Bff21: $siteUser = $form->get("\x73\151\x74\x65\x55\163\145\162")->getData(); goto A585f; c9c51: $this->createNodejsSite($domainName, $nodejsVersion, $port, $siteUser, $siteUserPassword); goto dca14; A5223: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\x61\x6e\147\145\x72", $this->translator->trans("\x41\x6e\40\145\x72\162\x6f\x72\x20\150\x61\x73\40\157\143\x63\x75\x72\x72\145\144\54\40\145\x72\162\157\x72\40\155\145\163\163\x61\147\145\72\x20\x25\x65\162\162\157\x72\115\x65\163\163\x61\x67\x65\45", ["\45\x65\x72\x72\x6f\162\x4d\x65\163\163\x61\x67\145\x25" => $e->getMessage()])); } goto Ad5de; fa26a: if (true === $form->isValid()) { goto f6152; } goto b9d28; d0fbe: f6152: goto Ee7ae; d2f61: } public function newStaticSite(Request $request) : Response { goto Cc738; A424f: $form = $this->createStaticSiteForm(); goto F6235; Dcfc9: $response = $this->handleCreateStaticSiteForm($request, $form); goto Bb115; Dde06: return $response; goto ef500; ff916: fa2ab: goto Bcb80; Ee187: if (!(true === $form->isSubmitted())) { goto Ecaac; } goto Dcfc9; D477e: if (true === $hasPermissions) { goto afe01; } goto f8552; Ce531: return $response; goto ff916; f8552: $response = $this->redirect($this->generateUrl("\143\154\x70\137\x73\151\164\x65\163")); goto e8941; Cc738: $hasPermissions = $this->hasPermissions(); goto D477e; Bb115: if (!(false === is_null($response))) { goto fa2ab; } goto Ce531; D474d: $form->handleRequest($request); goto Ee187; D586d: afe01: goto C63b5; e55ba: E0bfd: goto Dde06; e8941: goto E0bfd; goto D586d; Bcb80: Ecaac: goto B4460; a170c: $response = $this->render("\106\x72\x6f\156\x74\x65\x6e\x64\57\123\x69\164\145\x2f\116\x65\x77\57\163\x74\141\x74\x69\x63\x2e\150\164\x6d\154\56\164\167\151\x67", ["\165\163\x65\162" => $user, "\146\157\x72\x6d" => $form->createView(), "\146\157\162\x6d\105\x72\x72\157\162\x73" => $this->formErrors]); goto e55ba; B4460: C2587: goto a170c; F6235: if (!(true === $request->isMethod("\120\117\x53\124"))) { goto C2587; } goto D474d; C63b5: $user = $this->getUser(); goto A424f; ef500: } private function createStaticSiteForm() : Form { goto A8b7b; ffc74: $form->add("\163\x75\x62\x6d\x69\x74", SubmitType::class, ["\x61\164\x74\x72" => ["\143\x6c\x61\x73\163" => "\142\x74\156\x20\142\164\x6e\x2d\x6c\x67\40\x62\x74\156\x2d\x62\154\165\x65"], "\154\x61\x62\x65\x6c" => "\103\x72\145\141\164\145"]); goto Ef06d; A8b7b: $form = $this->createForm("\x41\x70\x70\x5c\106\x6f\x72\155\x5c\x53\151\x74\145\x4e\145\x77\123\164\141\x74\151\143\x54\171\x70\145", [], ["\x61\x63\164\x69\157\x6e" => $this->generateUrl("\143\154\x70\x5f\x73\151\164\x65\x5f\163\164\x61\164\x69\143\x5f\x6e\x65\x77"), "\x6d\x65\164\x68\157\x64" => "\120\x4f\123\x54", "\x61\164\x74\x72" => []]); goto ffc74; Ef06d: return $form; goto ff77c; ff77c: } private function handleCreateStaticSiteForm(Request $request, Form $form) { goto F264b; c6e14: goto A4a41; goto A544a; F264b: if (true === $form->isValid()) { goto F0b5d; } goto d44e0; d44e0: $this->formErrors = $this->getErrorMessages($form); goto c6e14; D5418: try { goto C779b; B8b92: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\x73\x69\x74\x65\x73")); goto f380c; c8e63: $eventData = ["\163\151\x74\x65" => $domainName, "\x73\x69\164\145\125\x73\145\x72" => $siteUser]; goto F2a87; D6c57: $session->getFlashBag()->set("\x73\165\x63\x63\145\x73\163", $this->translator->trans("\x53\x69\164\x65\x20\150\141\x73\40\142\145\145\156\40\x63\162\x65\141\x74\145\144\x2e")); goto B8b92; c50a2: Fb943: goto F9a49; F9a49: $user = $this->getUser(); goto D68cf; A862a: $siteUser = $form->get("\163\x69\164\145\x55\x73\145\162")->getData(); goto C8ce3; Eed80: throw new \Exception(sprintf("\x56\x68\157\163\164\x20\x74\145\x6d\x70\x6c\x61\164\145\40\x22\45\x73\42\40\x6e\157\x74\x20\x66\157\165\156\144\56", $vhostTemplateName)); goto C21aa; D68cf: $this->createStaticSite($domainName, $siteUser, $siteUserPassword); goto c8e63; C21aa: goto Fb83a; goto c50a2; Ed0c2: $domainName = $form->get("\144\157\x6d\x61\151\x6e\116\x61\x6d\145")->getData(); goto A862a; C779b: $session = $request->getSession(); goto Ed0c2; Dced8: $vhostTemplateName = self::STATIC_SITE_VHOST_TEMPLATE_NAME; goto be807; C8ce3: $siteUserPassword = $form->get("\x73\x69\164\145\x55\163\145\x72\x50\x61\x73\x73\167\157\162\144")->getData(); goto Dced8; b6eea: Fb83a: goto b0d7e; be807: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto f4071; f4071: if (false === is_null($vhostTemplateEntity)) { goto Fb943; } goto Eed80; F2a87: EventQueue::addEvent(EventQueue::EVENT_SITE_STATIC_CREATE, $user, $eventData, $request); goto D6c57; f380c: return $response; goto b6eea; b0d7e: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\141\156\x67\x65\162", $this->translator->trans("\x41\x6e\40\145\162\162\157\162\x20\150\141\x73\40\x6f\x63\143\x75\162\162\x65\144\54\x20\x65\x72\x72\157\162\x20\155\x65\163\163\x61\147\145\72\40\x25\x65\162\x72\x6f\162\x4d\x65\x73\163\141\147\145\x25", ["\x25\x65\162\162\x6f\162\x4d\x65\163\163\x61\147\x65\x25" => $e->getMessage()])); } goto Ef1b6; A544a: F0b5d: goto D5418; Ef1b6: A4a41: goto F243e; F243e: } public function newPhpSite(Request $request) : Response { goto C0d26; E8f1e: $user = $this->getUser(); goto ea62d; a1fa1: if (!(true === $request->isMethod("\x50\x4f\x53\x54"))) { goto d956e; } goto Da562; d1dba: Fdecf: goto cac53; A3cd5: ff629: goto E8f1e; D3aaf: d9885: goto d1dba; ea62d: $form = $this->createPhpSiteForm(); goto a1fa1; b7675: $response = $this->render("\106\162\x6f\x6e\164\x65\x6e\x64\57\x53\151\x74\145\57\116\145\167\57\160\150\160\56\150\164\x6d\154\56\164\167\151\x67", ["\x75\163\145\x72" => $user, "\x66\157\x72\x6d" => $form->createView(), "\x66\x6f\x72\x6d\105\x72\x72\157\x72\163" => $this->formErrors]); goto fb8c4; cac53: d956e: goto b7675; B72a1: if (!(false === is_null($response))) { goto d9885; } goto Cf27f; e0737: if (!(true === $form->isSubmitted())) { goto Fdecf; } goto Eddbb; fb8c4: a0ae3: goto Dd155; Cf27f: return $response; goto D3aaf; b005c: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\x73\151\x74\145\x73")); goto c7fb3; Dd155: return $response; goto e4b54; B69d4: if (true === $hasPermissions) { goto ff629; } goto b005c; C0d26: $hasPermissions = $this->hasPermissions(); goto B69d4; c7fb3: goto a0ae3; goto A3cd5; Eddbb: $response = $this->handleCreatePhpSiteForm($request, $form); goto B72a1; Da562: $form->handleRequest($request); goto e0737; e4b54: } private function createPhpSiteForm() : Form { goto c42fe; C14f6: return $form; goto A2f36; c42fe: $form = $this->createForm("\x41\x70\160\x5c\x46\157\x72\x6d\134\x53\x69\164\x65\116\145\167\x50\150\160\124\x79\x70\x65", [], ["\141\x63\164\151\157\x6e" => $this->generateUrl("\x63\154\x70\137\163\151\x74\145\137\160\x68\x70\137\156\x65\x77"), "\x6d\x65\x74\x68\x6f\144" => "\x50\117\123\124", "\141\x74\164\162" => []]); goto d4dac; d4dac: $form->add("\163\x75\142\155\151\x74", SubmitType::class, ["\141\164\164\x72" => ["\143\x6c\141\163\x73" => "\142\x74\156\x20\x62\x74\x6e\x2d\154\147\40\x62\164\156\x2d\x62\154\x75\145"], "\x6c\141\142\x65\154" => "\103\x72\145\141\x74\145"]); goto C14f6; A2f36: } private function handleCreatePhpSiteForm(Request $request, Form $form) { goto b50d7; b2045: $this->formErrors = $this->getErrorMessages($form); goto A1e8a; a5911: try { goto B498a; ca50b: $phpVersion = $form->get("\x70\x68\160\126\x65\x72\x73\x69\x6f\x6e")->getData(); goto Aa179; E0635: b711e: goto Fe5fb; a03b6: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto Eb9ed; D9f51: $eventData = ["\x73\151\x74\145" => $domainName, "\166\x68\157\163\164\x54\x65\x6d\160\154\141\164\145\116\x61\155\145" => $vhostTemplateName, "\160\150\x70\126\145\x72\163\x69\157\x6e" => $phpVersion, "\x73\x69\x74\x65\x55\163\145\162" => $siteUser]; goto e3c76; Fc564: throw new \Exception(sprintf("\126\x68\157\163\164\x20\164\x65\x6d\x70\x6c\141\x74\x65\x20\x22\x25\x73\42\40\156\157\164\40\146\x6f\165\x6e\x64\x2e", $vhostTemplateName)); goto C46c7; B014e: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto fd816; A73d5: if (!(false === empty($vhostTemplateEntity->getRootDirectory()))) { goto D50a9; } goto f960f; Eb9ed: if (false === is_null($vhostTemplateEntity)) { goto b711e; } goto Fc564; f960f: $rootDirectory = sprintf("\x25\163\57\x25\163", $rootDirectory, ltrim(rtrim($vhostTemplateEntity->getRootDirectory(), "\x2f"), "\57")); goto Bd55e; Aa179: $siteUser = $form->get("\x73\151\x74\x65\x55\163\145\162")->getData(); goto A0aee; Dfb96: db081: goto d46dc; A80ee: $this->createPhpSite($domainName, $rootDirectory, $phpVersion, $vhostTemplateName, $siteUser, $siteUserPassword, $varnishCacheSettings); goto D9f51; B498a: $session = $request->getSession(); goto ffeea; ef4d9: $rootDirectory = $domainName; goto A73d5; b6b4e: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto d8baa; } goto B014e; ffeea: $vhostTemplateName = $form->get("\x61\x70\x70\154\x69\x63\141\164\151\x6f\156")->getData(); goto C7c09; e3c76: EventQueue::addEvent(EventQueue::EVENT_SITE_PHP_CREATE, $user, $eventData, $request); goto f2565; f2565: $session->getFlashBag()->set("\x73\165\x63\143\145\x73\x73", $this->translator->trans("\123\x69\164\145\x20\x68\x61\x73\40\x62\x65\x65\x6e\40\143\162\145\141\164\145\x64\x2e")); goto Ec9af; Bd55e: D50a9: goto E3d3a; Fe5fb: $user = $this->getUser(); goto ef4d9; A0aee: $siteUserPassword = $form->get("\163\x69\x74\x65\125\x73\x65\162\x50\x61\163\x73\x77\157\x72\144")->getData(); goto a03b6; F7db2: return $response; goto Dfb96; E3d3a: $varnishCacheSettings = []; goto b6b4e; C46c7: goto db081; goto E0635; Ec9af: $response = $this->redirect($this->generateUrl("\x63\x6c\160\137\x73\x69\164\x65\163")); goto F7db2; C7c09: $domainName = $form->get("\x64\157\x6d\x61\x69\x6e\x4e\x61\x6d\145")->getData(); goto ca50b; fd816: d8baa: goto A80ee; d46dc: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\x64\x61\156\x67\x65\x72", $this->translator->trans("\101\x6e\x20\x65\x72\x72\157\162\x20\x68\141\163\40\x6f\143\143\165\162\162\x65\144\54\x20\145\162\162\157\162\40\155\145\x73\x73\x61\x67\x65\72\x20\45\x65\162\x72\x6f\162\115\145\x73\163\141\147\x65\x25", ["\45\x65\162\x72\x6f\162\115\x65\x73\x73\x61\147\x65\45" => $e->getMessage()])); } goto df286; df286: b6ecc: goto ae5f7; b50d7: if (true === $form->isValid()) { goto defd3; } goto b2045; A1e8a: goto b6ecc; goto e5adc; e5adc: defd3: goto a5911; ae5f7: } public function newWordPressSite(Request $request) : Response { goto e9e73; e9e73: $hasPermissions = $this->hasPermissions(); goto F252c; Fa9df: $user = $this->getUser(); goto f0812; e7170: A80e0: goto e8088; f0812: $form = $this->createWordPressSiteForm(); goto Eb251; C93f1: F6406: goto Fa9df; D8a27: $response = $this->redirect($this->generateUrl("\x63\154\x70\137\x73\x69\164\x65\163")); goto C68c4; Ce838: if (!(false === is_null($response))) { goto d39b3; } goto Accc0; a7b0a: $response = $this->handleCreateWordPressSiteForm($request, $form); goto Ce838; C68c4: goto A80e0; goto C93f1; Efe5e: cc2ba: goto c02b0; Eb251: if (!(true === $request->isMethod("\120\x4f\x53\124"))) { goto B25da; } goto b0e75; b0e75: $form->handleRequest($request); goto D431b; D431b: if (!(true === $form->isSubmitted())) { goto cc2ba; } goto a7b0a; e8088: return $response; goto A5903; Accc0: return $response; goto F112d; c02b0: B25da: goto Bfd69; F252c: if (true === $hasPermissions) { goto F6406; } goto D8a27; Bfd69: $response = $this->render("\x46\x72\157\x6e\x74\x65\x6e\x64\57\x53\151\164\x65\x2f\x4e\145\167\x2f\x77\x6f\162\x64\160\162\145\163\x73\x2e\x68\164\155\154\56\x74\x77\x69\147", ["\165\x73\x65\x72" => $user, "\x66\157\x72\x6d" => $form->createView(), "\146\157\x72\155\105\162\162\157\162\x73" => $this->formErrors]); goto e7170; F112d: d39b3: goto Efe5e; A5903: } private function createWordPressSiteForm() : Form { goto de847; E398c: $form->add("\163\x75\142\x6d\151\164", SubmitType::class, ["\141\164\x74\x72" => ["\x63\154\x61\163\x73" => "\x62\164\156\40\x62\164\x6e\55\154\x67\40\142\x74\156\55\x62\x6c\x75\x65"], "\154\141\142\145\x6c" => "\x43\162\145\141\164\x65"]); goto Dc0bd; Dc0bd: return $form; goto c0ede; de847: $form = $this->createForm("\x41\160\x70\134\106\x6f\162\x6d\134\x53\151\x74\145\116\x65\x77\x57\157\162\144\120\162\145\163\x73\x54\171\160\145", [], ["\x61\143\x74\151\157\x6e" => $this->generateUrl("\x63\x6c\160\137\x73\151\164\x65\137\x77\157\162\x64\160\162\x65\163\163\x5f\156\x65\x77"), "\155\145\164\150\x6f\144" => "\x50\x4f\x53\124", "\x61\x74\x74\x72" => ["\151\144" => "\x6e\145\167\x2d\167\157\x72\x64\160\x72\145\163\x73\55\x73\151\x74\145\55\x66\157\162\155"]]); goto E398c; c0ede: } private function handleCreateWordPressSiteForm(Request $request, Form $form) { goto cdc74; cdc74: if (true === $form->isValid()) { goto e0073; } goto fddb9; fddb9: $this->formErrors = $this->getErrorMessages($form); goto C5d7a; ff1d8: try { goto E2554; d8d37: $databaseUserPassword = PasswordGenerator::generate(self::PASSWORD_LENGTH); goto aed78; b3d5e: $siteEntity->addDatabase($databaseEntity); goto d9d4c; b4a5f: $varnishCacheSettings = (array) json_decode($vhostTemplateEntity->getVarnishCacheSettings(), true); goto fd2c4; d8fef: $eventData = ["\163\151\164\145" => $domainName, "\x73\x69\x74\145\125\163\x65\162" => $siteUser]; goto ff363; Bfa73: $this->siteEntityManager->updateEntity($siteEntity); goto C1de7; c3ea0: $databaseUserEntity->setPermissions(DatabaseUserEntity::PERMISSIONS_READ_WRITE); goto b0067; fe70c: $siteUserPassword = $form->get("\x73\x69\164\x65\x55\x73\145\x72\x50\x61\163\163\x77\157\x72\x64")->getData(); goto d41aa; E7660: $generatedName = $this->generateNameFromDomainName($domainName); goto bdc1f; Fd335: $databaseManager->createUser($databaseUserEntity); goto Bfa73; E5f15: $siteCredentials[$this->translator->trans("\x44\141\164\x61\x62\x61\x73\x65")] = [$this->translator->trans("\x48\x6f\x73\164") => $activeDatabaseServerEntity->getHost(), $this->translator->trans("\120\157\x72\164") => $activeDatabaseServerEntity->getPort(), $this->translator->trans("\x44\141\x74\x61\x62\141\163\145\40\116\x61\x6d\x65") => $databaseName, $this->translator->trans("\104\141\x74\x61\x62\141\163\x65\x20\x55\163\145\x72\40\x4e\141\155\x65") => $databaseUserName, $this->translator->trans("\104\x61\x74\141\x62\x61\163\145\x20\x55\x73\145\x72\x20\x50\141\x73\163\x77\157\162\144") => $databaseUserPassword]; goto d0cf9; F83c7: $databaseManager->createDatabase($databaseEntity); goto Fd335; Fd313: $databaseUserEntity->setUserName($databaseUserName); goto b499d; B635f: $varnishCacheSettings = []; goto f3312; e5940: $session->set("\x73\151\164\x65\103\x72\145\144\x65\x6e\x74\151\141\154\x73", $siteCredentials); goto d8fef; aed78: $url = sprintf("\150\x74\164\160\163\72\57\x2f\x25\163", $siteEntity->getDomainName()); goto B75fd; e6eff: $databaseEntity->setSite($siteEntity); goto B5386; b0351: $databaseUserName = $this->getUniqueDatabaseUserName($generatedName); goto d8d37; d9d4c: $databaseManager = new DatabaseManager($activeDatabaseServerEntity); goto F83c7; Ad954: $session = $request->getSession(); goto B41fc; da708: $adminPassword = $form->get("\141\144\155\x69\156\x50\x61\x73\x73\167\x6f\162\144")->getData(); goto bfdcb; ff363: EventQueue::addEvent(EventQueue::EVENT_SITE_WORDPRESS_CREATE, $user, $eventData, $request); goto a090d; d0cf9: $siteCredentials["\127\x6f\162\144\x50\x72\145\163\x73"] = [$this->translator->trans("\x41\x64\x6d\x69\156\40\105\x2d\115\141\151\154") => $adminEmail, $this->translator->trans("\x41\144\155\151\x6e\x20\125\163\x65\162\x20\x4e\141\x6d\x65") => $adminUserName, $this->translator->trans("\x41\x64\x6d\151\x6e\x20\120\141\163\x73\x77\157\162\144") => $adminPassword, $this->translator->trans("\101\x64\x6d\151\x6e\x20\x55\x72\154") => sprintf("\150\x74\x74\x70\163\72\x2f\57\45\163\57\167\160\x2d\141\x64\155\x69\156\57", rtrim($domainName, "\57"))]; goto D1ab4; Dff41: $siteCredentials = [$this->translator->trans("\x53\x69\164\x65") => [$this->translator->trans("\x49\x50\40\x41\144\x64\x72\x65\163\x73") => $instance->getIpv4PublicIp(), $this->translator->trans("\x44\x6f\x6d\141\x69\156\40\x4e\141\155\x65") => sprintf("\150\x74\x74\160\x73\72\x2f\57\x25\163", $domainName), $this->translator->trans("\123\151\164\x65\x20\125\x73\x65\x72") => $siteUser, $this->translator->trans("\120\x61\163\163\x77\157\162\144") => $siteUserPassword]]; goto b043d; E2554: $user = $this->getUser(); goto Ad954; Ffd41: $databaseEntity->addUser($databaseUserEntity); goto b3d5e; B41fc: $domainName = $form->get("\x64\x6f\155\141\x69\x6e\x4e\141\x6d\145")->getData(); goto E7660; E8006: $instance = $request->attributes->get("\151\x6e\163\164\141\x6e\143\x65"); goto Dff41; b043d: if (!(false === is_null($siteEntity))) { goto E5015; } goto Ab9a1; B5386: $databaseUserEntity = $this->databaseUserEntityManager->createEntity(); goto Fd313; B53cd: $adminUserName = $form->get("\x61\x64\x6d\x69\156\x55\163\x65\x72\x4e\141\155\x65")->getData(); goto da708; f3312: if (!(false === empty($vhostTemplateEntity->getVarnishCacheSettings()))) { goto A1ce1; } goto b4a5f; a47d8: return $response; goto c6cd3; dabb4: $databaseEntity = $this->databaseEntityManager->createEntity(); goto Ce045; bfdcb: $adminEmail = $form->get("\141\x64\x6d\151\x6e\105\155\x61\x69\x6c")->getData(); goto E6751; b0067: $databaseUserEntity->setDatabase($databaseEntity); goto Ffd41; Ab9a1: $databaseName = $this->getUniqueDatabaseName($generatedName); goto b0351; d3bef: $databaseEntity->setName($databaseName); goto e6eff; a5c23: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto E8006; E6751: $isMultiSite = $form->get("\155\165\154\164\x69\123\151\164\x65")->getData(); goto ba680; b499d: $databaseUserEntity->setPassword(Crypto::encrypt($databaseUserPassword)); goto c3ea0; B75fd: $title = $form->get("\163\x69\x74\145\124\x69\164\154\145")->getData(); goto B53cd; ba680: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto dabb4; bdc1f: $siteUser = $form->get("\x73\x69\x74\x65\125\x73\145\162")->getData(); goto fe70c; a090d: $response = $this->redirect($this->generateUrl("\143\154\x70\137\x73\x69\x74\x65\x5f\x77\157\x72\144\160\162\145\163\x73\137\x69\x6e\x73\164\141\x6c\154\x65\x64")); goto a47d8; Ce045: $databaseEntity->setDatabaseServer($activeDatabaseServerEntity); goto d3bef; A232c: $phpVersion = $vhostTemplateEntity->getPhpVersion(); goto B635f; D033e: $siteEntity = $this->createPhpSite($domainName, $domainName, $phpVersion, self::WORDPRESS_VHOST_TEMPLATE_NAME, $siteUser, $siteUserPassword, $varnishCacheSettings); goto a5c23; fd2c4: A1ce1: goto D033e; d41aa: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::WORDPRESS_VHOST_TEMPLATE_NAME); goto A232c; C1de7: $this->installWordPress($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail, $siteEntity, $activeDatabaseServerEntity, $databaseEntity, $databaseUserEntity); goto E5f15; D1ab4: E5015: goto e5940; c6cd3: } catch (\Exception $e) { $this->logger->exception($e); $session->getFlashBag()->set("\144\141\x6e\147\x65\162", $this->translator->trans("\101\x6e\40\x65\x72\x72\157\x72\x20\150\x61\x73\40\x6f\143\143\165\162\162\x65\144\54\40\x65\x72\162\157\x72\40\155\145\163\163\x61\x67\x65\x3a\x20\x25\x65\x72\162\157\x72\115\x65\x73\163\x61\x67\x65\x25", ["\x25\x65\x72\162\157\x72\x4d\145\163\x73\141\147\x65\45" => $e->getMessage()])); } goto Aaf30; C7277: e0073: goto ff1d8; C5d7a: goto Ed715; goto C7277; Aaf30: Ed715: goto ff3e9; ff3e9: } private function installWordPress(bool $isMultiSite, string $url, string $title, string $adminUserName, string $adminPassword, string $adminEmail, SiteEntity $siteEntity, DatabaseServerEntity $databaseServerEntity, DatabaseEntity $databaseEntity, DatabaseUserEntity $databaseUserEntity) : void { goto e113d; Eb85c: $wordPressInstaller = new WordPressInstaller($siteEntity); goto Abf0b; e9a5b: $databaseUserName = $databaseUserEntity->getUserName(); goto Db1d6; bcea6: Cf965: goto cf7a2; Abf0b: $wordPressInstaller->downloadAndExtractLatestVersion(); goto eeb4d; eeb4d: $wordPressInstaller->createConfig($databaseHost, $databaseName, $databaseUserName, $databaseUserPassword); goto bb186; c6f70: foreach ($this->wordPressMultiSiteConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\141\x6c\x75\145"], $config["\x72\x61\x77"]); bccd5: } goto Dfd86; C8d1b: foreach ($this->wordPressDefaultConfigValues as $key => $config) { $wordPressInstaller->setConfigValue($key, $config["\x76\x61\x6c\165\x65"], $config["\162\141\x77"]); f7d13: } goto C97ea; C97ea: d763e: goto a01fc; a01fc: if (!(true === $isMultiSite)) { goto Cf965; } goto ff64f; B42a6: $databaseName = $databaseEntity->getName(); goto e9a5b; Db1d6: $databaseUserPassword = Crypto::decrypt($databaseUserEntity->getPassword()); goto Eb85c; ff64f: $this->wordPressMultiSiteConfigValues["\104\x4f\x4d\x41\x49\116\x5f\x43\x55\122\122\105\116\x54\137\x53\x49\x54\105"]["\166\x61\x6c\x75\x65"] = $siteEntity->getDomainName(); goto c6f70; e113d: $databaseHost = sprintf("\45\163\x3a\x25\163", $databaseServerEntity->getHost(), $databaseServerEntity->getPort()); goto B42a6; bb186: $wordPressInstaller->installCore($isMultiSite, $url, $title, $adminUserName, $adminPassword, $adminEmail); goto C8d1b; Dfd86: b8ddb: goto bcea6; cf7a2: $wordPressInstaller->resetPermissions(); goto b44d8; b44d8: } private function createPhpSite(string $domainName, string $rootDirectory, string $phpVersion, string $vhostTemplateName, string $siteUser, string $siteUserPassword, array $varnishCacheSettings = []) : SiteEntity { goto F5b95; ccc16: $certificateEntity->setSite($siteEntity); goto A8705; ba19f: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto A0760; A03aa: $siteEntity->setRootDirectory($rootDirectory); goto b23da; Eb0b9: $phpSiteCreator->createNginxVhost(); goto Ac43f; b23da: if (!(false === empty($varnishCache))) { goto D1a09; } goto A0778; A0760: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Bb5de; cbe99: $subjectAlternativeNames[] = sprintf("\167\x77\167\56\45\163", $domainName); goto E3399; b81d1: $siteEntity->setCertificate($certificateEntity); goto F8193; c1746: $phpSiteCreator->createRootDirectory(); goto bbc1d; cc8b9: $phpSite->setVarnishCacheSettings($varnishCacheSettings); goto Aff42; d75cb: $phpSiteCreator->createPrivateKeyAndCertificate(); goto d0447; a01a2: $vhostTemplate = new PhpVhostTemplate($phpSite); goto Bce58; Ab0d2: $vhostTemplateEntity = $this->getVhostTemplateEntity($vhostTemplateName); goto fcde4; A8705: $rsaKeyGenerator = new RsaKeyGenerator(); goto cfd84; f1d30: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto Edbfc; C2f05: $subjectAlternativeNames = []; goto C794a; d44e6: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto f0256; b7f0a: if (!(true === $varnishCache)) { goto Def0d; } goto A6dc0; d0447: $phpSiteCreator->createPhpFpmPool(); goto f5ec7; E00a4: $phpSiteCreator->resetPermissions(); goto a01a2; E8fed: $phpSiteCreator = new PhpSiteCreator($phpSite); goto e1952; E3399: ebf60: goto Ab700; Df873: Acd30: goto Ca921; fec8c: $constraintViolationList->addAll($phpSettingsConstraints); goto f1d30; Ca921: $certificateEntity = $this->certificateEntityManager->createEntity(); goto ccc16; E94b0: $phpSettingsEntity->setSite($siteEntity); goto fa5ac; Ca249: $siteEntity->setPhpSettings($phpSettingsEntity); goto fbaac; f14a9: $phpSite->setRegistrableDomain($registrableDomain); goto d8481; Ca91f: $phpSite->setUserPassword($siteEntity->getUserPassword()); goto a5af8; Cb0cf: $siteEntity->setVhostTemplate($vhostTemplate); goto b5625; Ae614: $constraintViolationList->addAll($siteConstraints); goto fec8c; a48d9: $subdomain = $resolvedDomainName->subDomain()->toString(); goto A33d8; Db2da: d5fec: goto b0ea5; E47e0: $phpSite->setRootDirectory($siteEntity->getRootDirectory()); goto Df956; f0256: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto a48d9; C8788: $phpSettingsConstraints = $this->validator->validate($phpSettingsEntity); goto d1985; f5ec7: $phpSiteCreator->reloadPhpFpmService(); goto b7f0a; C7baf: $varnishCacheSettings = array_merge($defaultVarnishCacheSettings, $varnishCacheSettings); goto dd716; A2906: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto C8988; A8c14: $siteEntity->setDomainName($domainName); goto Efb50; b5625: $phpSettingsEntity = new PhpSettingsEntity(); goto Ca249; feb5c: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto ab10f; F140a: return $siteEntity; goto Bccd4; c5259: $phpSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto E8fed; C951d: $phpSite->setPhpSettings($phpSettingsEntity); goto c5259; Aff42: Def0d: goto Eb0b9; Edbfc: throw new \Exception(implode("\73\x20", $errorMessages)); goto Df873; Ab700: if (!(false === is_null($subdomain) && "\x77\x77\x77" == $subdomain)) { goto B10b1; } goto f8174; Bce58: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto f0ff8; A0778: $siteEntity->setVarnishCache(true); goto B7555; Bb5de: $vhostTemplate->build(); goto Ba3da; Fd1eb: $vhostTemplate = sprintf("\45\x73\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto Db2da; d31ed: A83a7: goto Ea9e2; cf2d8: $certificateEntity->setCsr($csr); goto feb5c; bba98: if (true === isset($_ENV["\101\x50\x50\x5f\x48\124\x54\x50\63"]) && "\164\x72\165\x65" === $_ENV["\x41\x50\x50\137\x48\x54\x54\x50\x33"]) { goto A83a7; } goto bd121; e1952: $phpSiteCreator->createUser(); goto c1746; ab10f: $certificateEntity->setCertificate($selfSignedCertificate); goto b81d1; Fbd7c: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto ba19f; A6dc0: $phpSite->setVarnishCache(true); goto F5f7a; af61c: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto B4002; E4a01: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto D2396; C794a: if (!(true === is_null($subdomain))) { goto ebf60; } goto cbe99; bbc1d: $phpSiteCreator->createLogrotateFile(); goto E515d; F8193: $phpSite = new PhpSite(); goto F45c1; D62a5: $this->siteEntityManager->updateEntity($siteEntity); goto F140a; fcde4: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto D3229; B4002: $csr = $csrGenerator->generate(); goto E4a01; fbaac: $phpSettingsEntity->setPhpVersion($phpVersion); goto E94b0; Af532: goto Dc743; goto d31ed; E515d: $phpSiteCreator->createIndexPhp(); goto d75cb; c6a4e: $rootDirectory = trim(rtrim(ltrim($rootDirectory, "\57")), "\x2f"); goto d44e6; d8481: $phpSite->setSubdomain($subdomain); goto E47e0; Ba3da: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto Dd2fa; a5af8: $phpSite->setDomainName($domainName); goto f14a9; Ac43f: $phpSiteCreator->reloadNginxService(); goto E00a4; eaf01: B10b1: goto cc0f9; f8174: $subjectAlternativeNames[] = $registrableDomain; goto eaf01; B7555: D1a09: goto a0cd8; cc0f9: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto af61c; fa5ac: $siteConstraints = $this->validator->validate($siteEntity); goto C8788; Df956: $phpSite->setCertificate($certificateEntity); goto C951d; f2847: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto cf2d8; Dd2fa: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto D62a5; D3229: $siteEntity = $this->siteEntityManager->createEntity(); goto B7e4e; F5b95: $varnishCache = false === empty($varnishCacheSettings) ? true : false; goto c6a4e; b0ea5: D9b1f: goto Cb0cf; B7e4e: $siteEntity->setType(SiteEntity::TYPE_PHP); goto A8c14; dd716: $phpSiteCreator->createVarnishCacheStructure($varnishCacheSettings); goto cc8b9; cfd84: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto C2f05; D2396: $certificateEntity->setDefaultCertificate(true); goto f2847; C19be: $constraintViolationList = new ConstraintViolationList(); goto Ae614; F45c1: $phpSite->setUser($siteEntity->getUser()); goto Ca91f; d1985: if (!(count($siteConstraints) || count($phpSettingsConstraints))) { goto Acd30; } goto C19be; F5f7a: $defaultVarnishCacheSettings = ["\x65\x6e\141\x62\x6c\145\x64" => false, "\x73\x65\162\166\x65\x72" => self::VARNISH_CACHE_SERVER, "\143\141\143\150\x65\x54\x61\x67\120\x72\x65\146\x69\170" => substr(md5(time()), 0, 4)]; goto C7baf; Dc783: $siteEntity->setUserPassword($siteUserPassword); goto A03aa; bd121: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\x2f\x2e\56\x2f\x2e\56\57\162\x65\163\x6f\x75\x72\143\x65\163\57\156\147\151\156\x78\x2f\166\x68\x6f\x73\164\137\x74\145\x6d\160\154\141\164\x65\x2f\162\145\144\151\162\145\143\164"); goto Af532; Efb50: $siteEntity->setUser($siteUser); goto Dc783; f0ff8: $vhostTemplate->resetProcessors(); goto Fbd7c; Cc411: Dc743: goto A2906; C8988: if (!(false === empty($redirectionVhostTemplate))) { goto d5fec; } goto Fd1eb; Ea9e2: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\x2e\57\56\x2e\x2f\x2e\x2e\57\162\145\x73\x6f\165\x72\x63\x65\163\x2f\x6e\x67\151\x6e\170\x2f\166\150\x6f\x73\164\x5f\164\145\155\160\154\x61\x74\x65\x2f\162\x65\144\151\162\145\x63\164\x2d\150\164\164\x70\x33"); goto Cc411; a0cd8: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto D9b1f; } goto bba98; A33d8: $subdomain = false === empty($subdomain) ? $subdomain : null; goto Ab0d2; Bccd4: } private function createNodejsSite(string $domainName, string $nodejsVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto Aaa7e; Eec0b: $nodejsSiteCreator->reloadNginxService(); goto f0abe; c17c3: dc329: goto bfea2; f0ec0: $certificateEntity->setCsr($csr); goto E8b0f; E8b0f: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto e3054; Af839: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto B5206; Aa428: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto Aa49c; Ae232: $vhostTemplate = new StaticVhostTemplate($nodejsSite); goto Aa428; edd1c: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto Ae172; E0de0: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto B482b; c0489: $nodejsSiteCreator = new NodejsSiteCreator($nodejsSite); goto B68a5; e269b: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto eb55f; Aee4f: $nodejsSite = new NodejsSite(); goto Eec4e; f651d: if (!(count($siteConstraints) || count($nodejsSettingsConstraints))) { goto E7d1d; } goto C2eac; bbf12: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto f0ec0; B5206: $csr = $csrGenerator->generate(); goto C4d33; B965e: $subdomain = false === empty($subdomain) ? $subdomain : null; goto ed3c4; C4d33: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto C6437; Da215: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto c2593; ff320: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto Af839; E75b9: $nodejsSiteCreator->createPrivateKeyAndCertificate(); goto B8555; Ae86f: $vhostTemplate->build(); goto Ad704; Cd924: $nodejsSiteCreator->createLogrotateFile(); goto A7940; c2593: $subdomain = $resolvedDomainName->subDomain()->toString(); goto B965e; d4e52: $certificateEntity->setSite($siteEntity); goto C71a4; A7940: $nodejsSiteCreator->createNvmDirectory(); goto Bed8b; e898d: $nodejsSite->setCertificate($certificateEntity); goto De08e; Ccf61: $siteEntity->setType(SiteEntity::TYPE_NODEJS); goto D9c91; A53bc: $nodejsSettingsEntity->setPort($port); goto f63d9; F92de: $siteEntity->setNodejsSettings($nodejsSettingsEntity); goto B6d42; C2eac: $constraintViolationList = new ConstraintViolationList(); goto d104b; dd995: $nodejsSettingsConstraints = $this->validator->validate($nodejsSettingsEntity); goto f651d; e2d65: $vhostTemplate = sprintf("\45\x73\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto daa42; Ccc9a: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto B7000; Bed8b: $nodejsSiteCreator->installNodejs(); goto E75b9; f0abe: $nodejsSiteCreator->resetPermissions(); goto Ae232; bfea2: $siteEntity->setVhostTemplate($vhostTemplate); goto a6a29; A0437: $siteConstraints = $this->validator->validate($siteEntity); goto dd995; C6437: $certificateEntity->setDefaultCertificate(true); goto bbf12; b0d5f: $nodejsSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto c0489; be52f: $subjectAlternativeNames[] = sprintf("\x77\167\167\x2e\x25\x73", $domainName); goto f04cb; Fabd0: $nodejsSiteCreator->createRootDirectory(); goto Cd924; a6a29: $nodejsSettingsEntity = new NodejsSettingsEntity(); goto F92de; eb55f: throw new \Exception(implode("\x3b\40", $errorMessages)); goto c2417; b0a35: $nodejsSite->setRegistrableDomain($registrableDomain); goto Edbc6; dd8a1: $nodejsSite->setUserPassword($siteEntity->getUserPassword()); goto cac46; Fcad9: B3e32: goto edd1c; f23de: if (!(true === is_null($subdomain) || "\167\x77\167" == $subdomain)) { goto dc329; } goto c2fc0; Edbc6: $nodejsSite->setSubdomain($subdomain); goto c0aa2; A841d: C4566: goto F9b6c; Aaa7e: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto Da215; A6d41: return $siteEntity; goto Fab69; F1c64: $subjectAlternativeNames[] = $registrableDomain; goto Fc5bd; Ad704: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto E0de0; c2fc0: if (true === isset($_ENV["\x41\x50\x50\x5f\x48\124\124\120\x33"]) && "\x74\162\165\145" === $_ENV["\x41\120\120\137\x48\124\124\120\x33"]) { goto C4566; } goto c391f; B7000: $siteEntity = $this->siteEntityManager->createEntity(); goto Ccf61; D9c91: $siteEntity->setDomainName($domainName); goto d8fff; C44ec: $certificateEntity = $this->certificateEntityManager->createEntity(); goto d4e52; ce588: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto bec77; B482b: $this->siteEntityManager->updateEntity($siteEntity); goto A6d41; D6d0c: $subjectAlternativeNames = []; goto e144e; bec77: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto d3d8f; f63d9: $nodejsSettingsEntity->setSite($siteEntity); goto A0437; e44da: $siteEntity->setCertificate($certificateEntity); goto Aee4f; f04cb: ec4fe: goto a6c15; F811b: goto B3e32; goto A841d; ed3c4: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::NODEJS_VHOST_TEMPLATE_NAME); goto Ccc9a; b5c6d: $siteEntity->setUserPassword($siteUserPassword); goto A3192; Fc5bd: E89e8: goto ff320; e144e: if (!(true === is_null($subdomain))) { goto ec4fe; } goto be52f; d104b: $constraintViolationList->addAll($siteConstraints); goto d0854; c2417: E7d1d: goto C44ec; e3054: $certificateEntity->setCertificate($selfSignedCertificate); goto e44da; d0854: $constraintViolationList->addAll($nodejsSettingsConstraints); goto e269b; cac46: $nodejsSite->setDomainName($domainName); goto b0a35; c391f: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\56\x2f\x2e\56\57\x2e\x2e\x2f\x72\x65\163\x6f\x75\162\x63\145\x73\x2f\x6e\147\151\x6e\170\x2f\x76\150\x6f\x73\164\x5f\x74\145\155\160\154\141\x74\145\x2f\x72\145\x64\x69\162\145\x63\x74"); goto F811b; B8555: $nodejsSiteCreator->createNginxVhost(); goto Eec0b; Aa49c: $vhostTemplate->resetProcessors(); goto ce588; De08e: $nodejsSite->setNodejsSettings($nodejsSettingsEntity); goto b0d5f; D9ed3: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto D6d0c; Ae172: if (!(false === empty($redirectionVhostTemplate))) { goto a5b92; } goto e2d65; daa42: a5b92: goto c17c3; c0aa2: $nodejsSite->setRootDirectory($siteEntity->getRootDirectory()); goto e898d; F9b6c: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\x2f\x2e\x2e\57\56\x2e\x2f\x72\145\163\157\165\x72\143\145\x73\57\156\x67\x69\156\170\57\166\x68\157\163\x74\137\x74\145\x6d\160\154\141\x74\x65\x2f\x72\145\x64\151\162\x65\143\164\55\150\x74\164\x70\63"); goto Fcad9; B68a5: $nodejsSiteCreator->createUser(); goto Fabd0; d3d8f: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto Ae86f; A3192: $siteEntity->setRootDirectory($domainName); goto f23de; a6c15: if (!(false === is_null($subdomain) && "\x77\x77\167" == $subdomain)) { goto E89e8; } goto F1c64; C71a4: $rsaKeyGenerator = new RsaKeyGenerator(); goto D9ed3; B6d42: $nodejsSettingsEntity->setNodejsVersion($nodejsVersion); goto A53bc; Eec4e: $nodejsSite->setUser($siteEntity->getUser()); goto dd8a1; d8fff: $siteEntity->setUser($siteUser); goto b5c6d; Fab69: } private function createPythonSite(string $domainName, string $pythonVersion, string $port, string $siteUser, string $siteUserPassword) : SiteEntity { goto e55f4; B4b61: $pythonSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto bef55; A3d98: $siteEntity = $this->siteEntityManager->createEntity(); goto eb35e; dc06a: $siteEntity->setUser($siteUser); goto Baaab; b76b9: $pythonSiteCreator->writePythonVersionFile(); goto Cbbb5; c6aac: $pythonSiteCreator->createLogrotateFile(); goto b76b9; A945b: $vhostTemplate->resetProcessors(); goto Eaf79; be312: $pythonSettingsConstraints = $this->validator->validate($pythonSettingsEntity); goto f9934; e2990: $siteConstraints = $this->validator->validate($siteEntity); goto be312; dbba8: $pythonSite->setSubdomain($subdomain); goto c03e8; Cecf5: $certificateEntity->setCertificate($selfSignedCertificate); goto A97f5; fd485: $certificateEntity->setSite($siteEntity); goto Cb644; fbcd4: goto E1c96; goto E3acb; b9aff: A2755: goto fd677; d9713: if (!(false === empty($redirectionVhostTemplate))) { goto bf5fb; } goto f256f; b10d6: $pythonSiteCreator->createUser(); goto ff816; A520f: $pythonSettingsEntity->setPort($port); goto a3bd9; c6f3b: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::PYTHON_VHOST_TEMPLATE_NAME); goto C3f50; a00b1: $certificateEntity = $this->certificateEntityManager->createEntity(); goto fd485; Af582: $constraintViolationList = new ConstraintViolationList(); goto E3dfd; Ee9e5: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto C44bd; b03e3: E1c96: goto f59a4; f256f: $vhostTemplate = sprintf("\x25\x73\x25\x73", $redirectionVhostTemplate, $vhostTemplate); goto cea07; de001: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto f1517; Bb70c: if (true === isset($_ENV["\101\120\120\x5f\x48\x54\x54\x50\63"]) && "\x74\x72\x75\x65" === $_ENV["\x41\120\120\137\110\x54\x54\x50\x33"]) { goto ce520; } goto C861a; C37c4: E508f: goto e0353; c3ae8: $subjectAlternativeNames = []; goto ed774; b6212: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto Ac233; b7449: $pythonSite = new PythonSite(); goto B3df1; Eaf79: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto B49e5; fec00: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto f8c4d; f8c4d: $certificateEntity->setDefaultCertificate(true); goto Ee9e5; a3bd9: $pythonSettingsEntity->setSite($siteEntity); goto e2990; C861a: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\56\x2f\56\56\x2f\56\x2e\x2f\x72\x65\x73\157\x75\x72\x63\145\163\57\156\147\x69\156\170\x2f\166\x68\x6f\163\164\137\164\145\155\x70\154\x61\164\x65\57\162\145\x64\151\162\x65\x63\164"); goto fbcd4; F3ab1: $subjectAlternativeNames[] = sprintf("\167\167\167\56\45\163", $domainName); goto b9aff; fc66d: Af090: goto A2325; D2164: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto A945b; Bbeb0: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto Fa0f1; A97f5: $siteEntity->setCertificate($certificateEntity); goto b7449; c4000: $subdomain = false === empty($subdomain) ? $subdomain : null; goto c6f3b; C15b5: if (!(true === is_null($subdomain) || "\x77\167\x77" == $subdomain)) { goto E508f; } goto Bb70c; df9ec: $this->siteEntityManager->updateEntity($siteEntity); goto Bbeb0; E3dfd: $constraintViolationList->addAll($siteConstraints); goto c7f1f; b2c58: $pythonSite->setCertificate($certificateEntity); goto ef9d9; Cee2a: $pythonSettingsEntity = new PythonSettingsEntity(); goto D20c3; ed774: if (!(true === is_null($subdomain))) { goto A2755; } goto F3ab1; Bd369: $vhostTemplate = new PythonVhostTemplate($pythonSite); goto D2164; a2e05: $pythonSite->setUserPassword($siteEntity->getUserPassword()); goto caee3; ff816: $pythonSiteCreator->createRootDirectory(); goto c6aac; F8989: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto dee04; daff7: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto Cecf5; A2325: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto de001; f9934: if (!(count($siteConstraints) || count($pythonSettingsConstraints))) { goto B2d8c; } goto Af582; ef9d9: $pythonSite->setPythonSettings($pythonSettingsEntity); goto B4b61; f0588: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto c3ae8; cea07: bf5fb: goto C37c4; c7f1f: $constraintViolationList->addAll($pythonSettingsConstraints); goto F8989; A768e: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto a6c66; C3f50: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto A3d98; e4770: B2d8c: goto a00b1; Ac233: $subdomain = $resolvedDomainName->subDomain()->toString(); goto c4000; Fa0f1: return $siteEntity; goto ef8c0; c03e8: $pythonSite->setRootDirectory($siteEntity->getRootDirectory()); goto b2c58; C44bd: $certificateEntity->setCsr($csr); goto daff7; F2ed7: $pythonSite->setRegistrableDomain($registrableDomain); goto dbba8; B49e5: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto A768e; E3acb: ce520: goto c61c6; Cb644: $rsaKeyGenerator = new RsaKeyGenerator(); goto f0588; c61c6: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\x2f\x2e\56\x2f\x2e\x2e\x2f\x72\145\163\157\165\162\143\x65\x73\x2f\x6e\x67\151\156\170\x2f\x76\150\157\x73\164\137\164\x65\155\x70\154\141\x74\145\57\x72\145\x64\151\x72\145\x63\164\55\150\164\164\160\63"); goto b03e3; c19b1: $pythonSettingsEntity->setPythonVersion($pythonVersion); goto A520f; caee3: $pythonSite->setDomainName($domainName); goto F2ed7; cf756: $siteEntity->setDomainName($domainName); goto dc06a; e55f4: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto b6212; a6c66: $vhostTemplate->build(); goto E0e47; Cbbb5: $pythonSiteCreator->createPrivateKeyAndCertificate(); goto bc3b2; dee04: throw new \Exception(implode("\x3b\x20", $errorMessages)); goto e4770; E0e47: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto df9ec; eb35e: $siteEntity->setType(SiteEntity::TYPE_PYTHON); goto cf756; B3df1: $pythonSite->setUser($siteEntity->getUser()); goto a2e05; Baaab: $siteEntity->setUserPassword($siteUserPassword); goto F7424; F7424: $siteEntity->setRootDirectory($domainName); goto C15b5; f1517: $csr = $csrGenerator->generate(); goto fec00; C1c21: $pythonSiteCreator->resetPermissions(); goto Bd369; ca7e7: $pythonSiteCreator->reloadNginxService(); goto C1c21; bc3b2: $pythonSiteCreator->createNginxVhost(); goto ca7e7; bda53: $subjectAlternativeNames[] = $registrableDomain; goto fc66d; f59a4: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto d9713; bef55: $pythonSiteCreator = new PythonSiteCreator($pythonSite); goto b10d6; D20c3: $siteEntity->setPythonSettings($pythonSettingsEntity); goto c19b1; e0353: $siteEntity->setVhostTemplate($vhostTemplate); goto Cee2a; fd677: if (!(false === is_null($subdomain) && "\167\x77\167" == $subdomain)) { goto Af090; } goto bda53; ef8c0: } private function createStaticSite(string $domainName, string $siteUser, string $siteUserPassword) : SiteEntity { goto F1554; c5e7c: $vhostTemplate = sprintf("\45\x73\45\x73", $redirectionVhostTemplate, $vhostTemplate); goto d4a3c; c78fb: $staticSiteCreator = new StaticSiteCreator($staticSite); goto E094d; Df431: $staticSiteCreator->createRootDirectory(); goto a2a45; F8592: $subdomain = false === empty($subdomain) ? $subdomain : null; goto fc5e8; E094d: $staticSiteCreator->createUser(); goto Df431; A2916: $staticSite->setCertificate($certificateEntity); goto D28ae; c393e: $csr = $csrGenerator->generate(); goto Ba2c9; De693: $siteEntity->setRootDirectory($domainName); goto deb54; abb05: $staticSite->setRegistrableDomain($registrableDomain); goto Df836; a4639: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto cb5f4; Dda48: Bf71c: goto E3bbf; A6707: $vhostTemplate->resetProcessors(); goto a4639; b66cf: $siteEntity->setCertificate($certificateEntity); goto e1bd1; af674: if (true === isset($_ENV["\101\x50\x50\x5f\x48\x54\x54\120\63"]) && "\164\162\x75\145" === $_ENV["\x41\x50\120\137\x48\124\x54\x50\63"]) { goto c090a; } goto Bc805; Bc08d: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto F09e4; B8bb1: $staticSiteCreator->createNginxVhost(); goto d7e37; c90ca: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto ce462; F8322: c090a: goto Ecf78; F09e4: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto c393e; e90d2: $siteConstraints = $this->validator->validate($siteEntity); goto D5038; Ba2c9: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto f70af; B11d7: $vhostTemplate = new StaticVhostTemplate($staticSite); goto F927e; a2a45: $staticSiteCreator->createLogrotateFile(); goto e5211; F1554: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto a1f55; A0141: if (!(false === empty($redirectionVhostTemplate))) { goto b3a19; } goto c5e7c; f1f5d: $subdomain = $resolvedDomainName->subDomain()->toString(); goto F8592; fa41d: $constraintViolationList->addAll($siteConstraints); goto fa9ce; D28ae: $staticSite->setVhostTemplate($siteEntity->getVhostTemplate()); goto c78fb; e7027: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto def6e; e1bd1: $staticSite = new StaticSite(); goto ff34c; def6e: $certificateEntity->setCertificate($selfSignedCertificate); goto b66cf; Db915: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto b1023; D5038: if (!count($siteConstraints)) { goto Fd80a; } goto b3108; b1023: $siteEntity = $this->siteEntityManager->createEntity(); goto C293c; c90fa: $certificateEntity = $this->certificateEntityManager->createEntity(); goto F6cdd; ce462: $vhostTemplate->build(); goto B66e7; d4a3c: b3a19: goto Dda48; deb54: if (!(true === is_null($subdomain) || "\167\167\x77" == $subdomain)) { goto Bf71c; } goto af674; e5211: $staticSiteCreator->createIndexHtml(); goto D2ed7; F927e: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto A6707; d7038: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto dc9cf; E3bbf: $siteEntity->setVhostTemplate($vhostTemplate); goto e90d2; D642a: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto De788; } goto a166d; B66e7: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto fd514; fa9ce: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto E328f; d7e37: $staticSiteCreator->reloadNginxService(); goto B74e3; ff34c: $staticSite->setUser($siteEntity->getUser()); goto C5130; a166d: $subjectAlternativeNames[] = $registrableDomain; goto f30e5; f70af: $certificateEntity->setDefaultCertificate(true); goto A7457; C5130: $staticSite->setUserPassword($siteEntity->getUserPassword()); goto Efb41; Ed38a: $siteEntity->setUserPassword($siteUserPassword); goto De693; a1f55: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto f1f5d; f30e5: De788: goto Bc08d; A2a9d: goto aa3bd; goto F8322; b4c14: $siteEntity->setUser($siteUser); goto Ed38a; b3108: $constraintViolationList = new ConstraintViolationList(); goto fa41d; F6cdd: $certificateEntity->setSite($siteEntity); goto bf6f3; C293c: $siteEntity->setType(SiteEntity::TYPE_STATIC); goto f8d7c; c20da: aa3bd: goto c8c11; dc9cf: $subjectAlternativeNames = []; goto b5952; D2ed7: $staticSiteCreator->createPrivateKeyAndCertificate(); goto B8bb1; Efb41: $staticSite->setDomainName($domainName); goto abb05; b6b6f: $certificateEntity->setCsr($csr); goto e7027; bf6f3: $rsaKeyGenerator = new RsaKeyGenerator(); goto d7038; f8d7c: $siteEntity->setDomainName($domainName); goto b4c14; E328f: throw new \Exception(implode("\73\x20", $errorMessages)); goto B8042; B74e3: $staticSiteCreator->resetPermissions(); goto B11d7; Df836: $staticSite->setSubdomain($subdomain); goto Ef46c; d32ee: $subjectAlternativeNames[] = sprintf("\167\167\167\56\x25\x73", $domainName); goto F7c75; fd514: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto De78b; F7c75: ee926: goto D642a; De78b: $this->siteEntityManager->updateEntity($siteEntity); goto F63be; Ecf78: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\56\56\x2f\x2e\56\x2f\x2e\56\57\x72\145\163\157\165\x72\143\x65\x73\57\x6e\147\x69\156\x78\x2f\166\150\x6f\163\x74\x5f\x74\x65\155\160\154\x61\x74\145\57\x72\x65\144\x69\x72\x65\143\164\x2d\150\x74\164\160\63"); goto c20da; Ef46c: $staticSite->setRootDirectory($siteEntity->getRootDirectory()); goto A2916; F63be: return $siteEntity; goto e2f18; fc5e8: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::STATIC_SITE_VHOST_TEMPLATE_NAME); goto Db915; Bc805: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\x2e\x2e\x2f\x2e\x2e\57\56\56\57\162\x65\x73\157\x75\162\143\145\163\57\x6e\x67\x69\156\x78\x2f\166\150\157\x73\x74\x5f\164\145\155\x70\154\x61\164\x65\57\162\x65\x64\151\162\x65\x63\164"); goto A2a9d; c8c11: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto A0141; cb5f4: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto c90ca; A7457: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto b6b6f; b5952: if (!(true === is_null($subdomain))) { goto ee926; } goto d32ee; B8042: Fd80a: goto c90fa; e2f18: } private function createReverseProxySite(string $domainName, string $reverseProxyUrl, string $siteUser, string $siteUserPassword) : SiteEntity { goto eeee6; Cfc69: $reverseProxySite->setRegistrableDomain($registrableDomain); goto e5e5d; D7aa1: $siteEntity->setType(SiteEntity::TYPE_REVERSE_PROXY); goto D25c8; e20b5: throw new \Exception(implode("\x3b\40", $errorMessages)); goto dd85e; F7366: $subdomain = $resolvedDomainName->subDomain()->toString(); goto d0a7d; e5e5d: $reverseProxySite->setSubdomain($subdomain); goto Ebdc0; Fcf60: D3605: goto e0b65; b8d6b: c6565: goto ea9a3; cfd70: if (!count($siteConstraints)) { goto da9a5; } goto E6300; Bf193: $vhostTemplate = new ReverseProxyVhostTemplate($reverseProxySite); goto E45d2; ec095: $certificateEntity->setCsr($csr); goto E2e98; f2419: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\x2f\56\x2e\57\x2e\56\57\56\x2e\x2f\162\x65\163\x6f\165\162\143\x65\163\57\156\x67\151\156\170\57\166\x68\x6f\163\164\137\164\145\x6d\160\154\141\164\x65\57\x72\145\144\x69\162\145\143\164"); goto E0629; bbd3d: $siteEntity->setUserPassword($siteUserPassword); goto D2d6c; C51c1: D4235: goto A26c2; F9422: $subjectAlternativeNames[] = sprintf("\167\x77\x77\x2e\45\x73", $domainName); goto b8d6b; A9fb0: $siteEntity->setUser($siteUser); goto bbd3d; e723e: $certificateEntity->setDefaultCertificate(true); goto ebef0; f1f68: $reverseProxySite->setUser($siteEntity->getUser()); goto b5b5a; fb21b: if (true === isset($_ENV["\x41\120\120\137\110\124\124\x50\63"]) && "\164\x72\165\145" === $_ENV["\x41\120\120\x5f\110\124\x54\x50\x33"]) { goto b2f3e; } goto f2419; Af36d: $redirectionVhostTemplate = file_get_contents($redirectionVhostTemplateFile); goto ecb8b; ebef0: $certificateEntity->setType(CertificateEntity::TYPE_SELF_SIGNED); goto ec095; a5d4d: $vhostTemplate->build(); goto fa0bd; e04f4: $redirectionVhostTemplateFile = realpath(dirname(__FILE__) . "\57\x2e\56\x2f\56\x2e\57\x2e\x2e\x2f\x72\145\x73\157\165\x72\143\x65\163\x2f\156\x67\151\156\170\x2f\166\x68\157\x73\164\137\164\145\x6d\160\154\141\x74\x65\57\x72\x65\144\x69\162\x65\143\164\55\x68\x74\x74\160\x33"); goto acb51; dd85e: da9a5: goto d8dc4; Ecf97: $reversProxySiteCreator->createLogrotateFile(); goto E593a; e6cd4: $subjectAlternativeNames[] = $registrableDomain; goto C51c1; B2ae8: $siteEntity->setApplication($vhostTemplateEntity->getName()); goto fd340; ad217: $reverseProxySite->setCertificate($certificateEntity); goto A46b4; Ad0dc: $vhostTemplate = sprintf("\x25\163\x25\163", $redirectionVhostTemplate, $vhostTemplate); goto Fcf60; A3eb7: $vhostTemplate = $vhostTemplateEntity->getTemplate(); goto Fe782; ffee6: $vhostTemplate->addProcessor(new RedirectServerNameProcessor()); goto Abdd8; E0629: goto A86d9; goto fc5df; e827e: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto F7366; e73a5: $certificateEntity->setSite($siteEntity); goto e3e3e; f784f: $reversProxySiteCreator->reloadNginxService(); goto dd71b; e0b65: a095d: goto D620d; e23ae: $reversProxySiteCreator->createRootDirectory(); goto Ecf97; F7f1d: if (!(true === is_null($subdomain))) { goto c6565; } goto F9422; c72ac: $vhostTemplate->resetProcessors(); goto D7d73; E45d2: $vhostTemplate->setContent($siteEntity->getVhostTemplate()); goto c72ac; fee0b: $reversProxySiteCreator->createUser(); goto e23ae; fd340: $this->siteEntityManager->updateEntity($siteEntity); goto Cfabd; C24a9: if (!(true === is_null($subdomain) || "\x77\167\167" == $subdomain)) { goto a095d; } goto fb21b; fc5df: b2f3e: goto e04f4; Cc675: $reverseProxySite->setDomainName($domainName); goto Cfc69; fa0bd: $siteEntity->setVhostTemplate($vhostTemplate->getContent()); goto B2ae8; Ebe72: $reverseProxySite = new ReverseProxySite(); goto f1f68; d0a7d: $subdomain = false === empty($subdomain) ? $subdomain : null; goto d361e; Ebc64: $siteEntity->setReverseProxyUrl($reverseProxyUrl); goto C24a9; F2f4c: $csr = $csrGenerator->generate(); goto Bb4a1; D7d73: $vhostTemplate->addProcessor(new ServerNameProcessor()); goto ffee6; E593a: $reversProxySiteCreator->createPrivateKeyAndCertificate(); goto Ea288; Abdd8: $vhostTemplate->addProcessor(new RedirectDomainProcessor()); goto a5d4d; d8dc4: $certificateEntity = $this->certificateEntityManager->createEntity(); goto e73a5; Cfabd: return $siteEntity; goto D4d8f; A26c2: $distinguishedName = new DistinguishedName($domainName, $subjectAlternativeNames); goto d0f94; eeee6: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto e827e; Ad897: $subjectAlternativeNames = []; goto F7f1d; Bf9b5: $errorMessages = $this->getConstraintViolationListErrorMessages($constraintViolationList); goto e20b5; d0f94: $csrGenerator = new CsrGenerator($privateKey, $distinguishedName); goto F2f4c; Bb4a1: $selfSignedCertificate = Openssl::createSelfSignedCertificate($privateKey, $csr); goto e723e; b5b5a: $reverseProxySite->setUserPassword($siteEntity->getUserPassword()); goto Cc675; Fc849: $constraintViolationList->addAll($siteConstraints); goto Bf9b5; D2d6c: $siteEntity->setRootDirectory($domainName); goto Ebc64; d361e: $vhostTemplateEntity = $this->getVhostTemplateEntity(self::REVERSE_PROXY_VHOST_TEMPLATE_NAME); goto A3eb7; E2e98: $certificateEntity->setPrivateKey($privateKey->getPEM()); goto b9413; e3e3e: $rsaKeyGenerator = new RsaKeyGenerator(); goto a748c; b9413: $certificateEntity->setCertificate($selfSignedCertificate); goto A366e; Ebdc0: $reverseProxySite->setRootDirectory($siteEntity->getRootDirectory()); goto ad217; D620d: $siteEntity->setVhostTemplate($vhostTemplate); goto F9afa; D25c8: $siteEntity->setDomainName($domainName); goto A9fb0; ecb8b: if (!(false === empty($redirectionVhostTemplate))) { goto D3605; } goto Ad0dc; a748c: $privateKey = $rsaKeyGenerator->generatePrivateKey(); goto Ad897; ea9a3: if (!(false === is_null($subdomain) && "\x77\167\167" == $subdomain)) { goto D4235; } goto e6cd4; A46b4: $reverseProxySite->setReverseProxyUrl($reverseProxyUrl); goto f002e; acb51: A86d9: goto Af36d; dd71b: $reversProxySiteCreator->resetPermissions(); goto Bf193; F9afa: $siteConstraints = $this->validator->validate($siteEntity); goto cfd70; f002e: $reverseProxySite->setVhostTemplate($siteEntity->getVhostTemplate()); goto D8594; Fe782: $siteEntity = $this->siteEntityManager->createEntity(); goto D7aa1; A366e: $siteEntity->setCertificate($certificateEntity); goto Ebe72; E6300: $constraintViolationList = new ConstraintViolationList(); goto Fc849; D8594: $reversProxySiteCreator = new ReverseProxySiteCreator($reverseProxySite); goto fee0b; Ea288: $reversProxySiteCreator->createNginxVhost(); goto f784f; D4d8f: } public function installedWordPressSite(Request $request) : Response { goto f525f; f525f: $session = $request->getSession(); goto ca5ea; ca5ea: $siteCredentials = $session->get("\163\151\x74\x65\x43\x72\145\144\x65\x6e\164\151\141\x6c\x73"); goto Ab7aa; F1f01: goto C8894; goto a07e2; E9f9c: C8894: goto A87cf; b6091: $response = $this->render("\x46\162\157\x6e\164\x65\x6e\144\57\123\151\x74\145\x2f\x4e\145\x77\x2f\x77\x6f\162\x64\x70\x72\x65\163\x73\55\151\156\x73\164\x61\x6c\x6c\145\x64\x2e\150\164\155\154\x2e\164\x77\x69\x67", ["\x73\x69\164\145\103\x72\145\144\x65\x6e\x74\x69\141\154\x73" => $siteCredentials]); goto E39c0; A87cf: return $response; goto A875e; Ab7aa: if (false === empty($siteCredentials)) { goto c2f5b; } goto A1912; a07e2: c2f5b: goto e02ce; e02ce: $siteCredentials = $this->renderSiteCredentials($siteCredentials); goto b6091; E39c0: return $response; goto E9f9c; A1912: $response = $this->redirect($this->generateUrl("\x63\x6c\x70\137\163\x69\164\x65\x73")); goto F1f01; A875e: } private function renderSiteCredentials(array $siteCredentials) : string { goto A859c; d8b92: return $renderedCredentials; goto ccb9b; A859c: $renderedCredentials = ''; goto Cd4eb; Cd4eb: foreach ($siteCredentials as $section => $sectionData) { goto ac0f2; C6daa: foreach ($sectionData as $key => $value) { $renderedCredentials .= sprintf("\x25\163\72\40\45\x73", $key, $value) . PHP_EOL; Fa3c7: } goto D8d33; E6088: $renderedCredentials .= PHP_EOL; goto b8d2f; Aed07: $renderedCredentials .= "\x2d\55\x2d\x2d\55\55\55\55\x2d\55\55\55\55\x2d\55\55\55\55\x2d\x2d\55\x2d\55\x2d\55\x2d\x2d\x2d\x2d\55\55\x2d\55\x2d\55\x2d\55\x2d\x2d\55\x2d\x2d\55\x2d\x2d\55\x2d\x2d\55\x2d\x2d\55\55\x2d" . PHP_EOL; goto C6daa; ac0f2: $renderedCredentials .= $section . PHP_EOL; goto Aed07; D8d33: ea206: goto E6088; b8d2f: C896a: goto d3880; d3880: } goto A89b8; A89b8: cb1e0: goto d8b92; ccb9b: } private function getVhostTemplateEntity(string $name) : mixed { goto bcc4f; bcc4f: $vhostTemplateEntity = $this->vhostTemplateEntityManager->findOneByName($name); goto Ac339; d6508: ef935: goto bf16f; bf16f: return $vhostTemplateEntity; goto C3808; E1f5d: throw new \Exception($this->translator->trans("\x56\150\x6f\163\164\40\124\x65\155\160\x6c\141\164\145\40\45\x76\x68\157\x73\164\124\145\x6d\160\x6c\141\164\145\x25\40\x64\157\x65\163\40\x6e\157\164\x20\145\170\151\x73\164\56", ["\x25\166\x68\x6f\163\x74\x54\x65\155\160\x6c\x61\x74\x65\45" => $name])); goto d6508; Ac339: if (!(true === is_null($vhostTemplateEntity))) { goto ef935; } goto E1f5d; C3808: } private function getConstraintViolationListErrorMessages(ConstraintViolationList $constraintViolationList) : array { goto Fce99; D31f5: foreach ($constraintViolationList as $constraint) { $errorMessages[] = sprintf("\x25\x73\x3a\40\45\x73", $constraint->getPropertyPath(), $constraint->getMessage()); cd6d9: } goto ae7bc; ee0f8: return $errorMessages; goto abf75; Fce99: $errorMessages = []; goto D31f5; ae7bc: Deb36: goto ee0f8; abf75: } private function generateNameFromDomainName(string $domainName) : string { goto Bef02; f2477: b82e9: goto F2701; b1ce4: $subdomain = $resolvedDomainName->subDomain()->toString(); goto C327d; b4fbf: $name = $explodedRegistrableDomain[0] ?? ''; goto A4962; Bef02: $resolvedDomainName = $this->domainNameParser->resolveDomainName($domainName); goto C38c8; C3a54: return $name; goto bd84a; Eb57b: if ("\x77\x77\x77" == $subdomain) { goto Decf0; } goto b4fbf; B2d72: $name = sprintf("\45\x73\x2d\x25\163", $explodedRegistrableDomain[0] ?? '', implode("\x2d", $explodedSubdomain)); goto f2477; F2701: goto bc1e0; goto B0ba9; C327d: $explodedRegistrableDomain = explode("\56", $registrableDomain); goto Eb57b; C38c8: $registrableDomain = $resolvedDomainName->registrableDomain()->toString(); goto b1ce4; B0ba9: Decf0: goto D3e61; A3b7a: bc1e0: goto C3a54; A4962: if (!(false === empty($subdomain))) { goto b82e9; } goto F0cda; F0cda: $explodedSubdomain = explode("\x2e", $subdomain); goto B2d72; D3e61: $name = $explodedRegistrableDomain[0] ?? ''; goto A3b7a; bd84a: } private function getUniqueDatabaseName(string $databaseName) : string { goto a4db0; abdf0: $i++; goto C8d54; C1121: $i = 0; goto d7a9b; a4db0: $uniqueDatabaseName = $databaseName; goto A2e96; e586d: $databaseExists = in_array($uniqueDatabaseName, $databases); goto abdf0; d7a9b: $activeDatabaseServerEntity = $this->databaseServerEntityManager->getActiveDatabaseServer(); goto e0c98; Cbe8e: d47c6: goto ef51a; A2e96: if (!(strlen($uniqueDatabaseName) <= 3)) { goto Ddd04; } goto be171; D0c65: db059: goto D494e; D494e: if (!(0 < $i)) { goto ae79f; } goto D9e99; D9e99: $uniqueDatabaseName = sprintf("\45\x73\55\x25\x73", $databaseName, $i); goto e1250; e1250: ae79f: goto e586d; e0c98: $databaseConnection = new DatabaseConnection($activeDatabaseServerEntity); goto e2013; C8d54: if (true === $databaseExists) { goto db059; } goto Cbe8e; e2013: $databases = $databaseConnection->getDatabases(); goto D0c65; e7ed1: Ddd04: goto C1121; be171: $uniqueDatabaseName = sprintf("\x25\x73\x2d\144\x62", $uniqueDatabaseName); goto e7ed1; ef51a: return $uniqueDatabaseName; goto b77aa; b77aa: } private function getUniqueDatabaseUserName(string $databaseUserName) : string { goto Ba68f; Ba68f: $uniqueDatabaseUserName = $databaseUserName; goto Aa14b; A370f: Bb30c: goto C3b13; Aa14b: if (!(strlen($uniqueDatabaseUserName) <= 3)) { goto D64e9; } goto A2ad3; aa8ee: if (false === is_null($databaseUserEntity)) { goto Dbe31; } goto A370f; D9f1d: efb4d: goto d547c; d547c: $databaseUserEntity = $this->databaseUserEntityManager->findOneByUserName($uniqueDatabaseUserName); goto b630e; De394: $i = 0; goto f1777; f1777: Dbe31: goto ef653; db2ac: $uniqueDatabaseUserName = sprintf("\x25\163\55\45\x73", $databaseUserName, $i); goto D9f1d; Eff93: D64e9: goto De394; ef653: if (!(0 < $i)) { goto efb4d; } goto db2ac; A2ad3: $uniqueDatabaseUserName = sprintf("\x25\163\x2d\144\x62", $uniqueDatabaseUserName); goto Eff93; C3b13: $uniqueDatabaseUserName = mb_substr($uniqueDatabaseUserName, 0, 32); goto D699e; D699e: return $uniqueDatabaseUserName; goto b620d; b630e: $i++; goto aa8ee; b620d: } private function hasPermissions() : bool { goto B62d9; a7cf7: Bf77f: goto d5309; B74f1: if (!(UserEntity::ROLE_USER != $user->getRole())) { goto Bf77f; } goto Dc197; d5309: return false; goto b702d; Dc197: return true; goto a7cf7; B62d9: $user = $this->getUser(); goto B74f1; b702d: } }
